@@ -4,12 +4,14 @@ except ImportError:
     pass
 import tkinter as tk
 import tkinter.ttk as ttk
-from ctypes import windll
+from ctypes import windll, POINTER, Structure, c_bool, sizeof, windll, pointer, c_int
+from ctypes.wintypes import DWORD, HWND, ULONG
 from enum import Enum
 from typing import Literal
 
 from tkdev.devicon import Icon_Empty
 from tkdev.devresize import DevResize
+from tkdev.devnet import WindowEffect
 
 try:
     from win32gui import *
@@ -65,6 +67,42 @@ def Install_ALL(Basic=True, Pypi="https://pypi.tuna.tsinghua.edu.cn/simple/"):
     Install("tkcap", Basic=Basic, Pypi=Pypi)
 
 
+class AccentState(Enum):
+    ACCENT_DISABLED = 0,
+    ACCENT_ENABLE_GRADIENT = 1,
+    ACCENT_ENABLE_TRANSPARENTGRADIENT = 2,
+    ACCENT_ENABLE_BLURBEHIND = 3,
+    ACCENT_ENABLE_ACRYLICBLURBEHIND = 4,
+    ACCENT_INVALID_STATE = 5,
+
+
+class WindowComPositionAttribute(Enum):
+    WCA_UNDEFINED = 0,
+    WCA_NCRENDERING_ENABLED = 1,
+    WCA_NCRENDERING_POLICY = 2,
+    WCA_TRANSITIONS_FORCEDISABLED = 3,
+    WCA_ALLOW_NCPAINT = 4,
+    WCA_CAPTION_BUTTON_BOUNDS = 5,
+    WCA_NONCLIENT_RTL_LAYOUT = 6,
+    WCA_FORCE_ICONIC_REPRESENTATION = 7,
+    WCA_EXTENDED_FRAME_BOUNDS = 8,
+    WCA_HAS_ICONIC_BITMAP = 9,
+    WCA_THEME_ATTRIBUTES = 10,
+    WCA_NCRENDERING_EXILED = 11,
+    WCA_NCADORNMENTINFO = 12,
+    WCA_EXCLUDED_FROM_LIVEPREVIEW = 13,
+    WCA_VIDEO_OVERLAY_ACTIVE = 14,
+    WCA_FORCE_ACTIVEWINDOW_APPEARANCE = 15,
+    WCA_DISALLOW_PEEK = 16,
+    WCA_CLOAK = 17,
+    WCA_CLOAKED = 18,
+    WCA_ACCENT_POLICY = 19,
+    WCA_FREEZE_REPRESENTATION = 20,
+    WCA_EVER_UNCLOAKED = 21,
+    WCA_VISUAL_OWNER = 22,
+    WCA_LAST = 23
+
+
 class DwmWindowAttribute(Enum):
     DWMWA_NCRENDERING_ENABLED = 1
     DWMWA_NCRENDERING_POLICY = 2
@@ -92,10 +130,36 @@ class DwmWindowAttribute(Enum):
     DWMWA_LAST = 24
 
 
+class Accent_Poltcy(Structure):
+    """ 设置客户区的具体属性 """
+    _fields_ = [
+        ('AccentState', DWORD),
+        ('AccentFlags', DWORD),
+        ('GradientColor', DWORD),
+        ('AnimationId', DWORD),
+    ]
+
+
+class WindowComPositionAttributeData(Structure):
+    _fields_ = [
+        ('Attribute', DWORD),
+        ('Data', POINTER(Accent_Poltcy)),  # POINTER()接收任何ctypes类型，并返回一个指针类型
+        ('SizeOfData', ULONG),
+    ]
+
+
 def dwm_set_window_attribute(window: tk.Tk, attribute, value):
     dwm.DwmSetWindowAttribute(GetParent(window.winfo_id()), attribute, value)
 
 
+def window_move(widget: tk.Widget, window: tk.Tk):
+    def move(evt):
+        ReleaseCapture()
+        SendMessage(GetParent(window.winfo_id()), WM_SYSCOMMAND,
+                    SC_MOVE + HTCAPTION, 0)
+    widget.bind("<B1-Motion>", move)
+
+
 def window_dark(window: tk.Tk):
     dwm.DwmSetWindowAttribute(GetParent(window.winfo_id()), DWMWA_USE_IMMERSIVE_DARK_MODE, True)
 
@@ -107,7 +171,7 @@ def window_light(window: tk.Tk):
 def window_screenshot(window: tk.Tk, image_name: str = "Image.png"):
     from tkcap import CAP
     cap = CAP(window)
-    window.after(20, cap.capture(image_name))
+    window.after(800, cap.capture(image_name))
     return cap
 
 
@@ -116,6 +180,10 @@ def window_acrylic(window: tk.Tk, dark=False, acrylic: bool = False, hexColor: b
     GlobalBlur(GetParent(window.winfo_id()), hexColor=hexColor, Acrylic=acrylic, Dark=dark, QWidget=window)
 
 
+def window_acrylic2(window: tk.Tk, shadow: bool = True):
+    effent = WindowEffect(GetParent(window.winfo_id()), isEnableShadow=shadow)
+
+
 def window_long(window: tk.Tk, long):
     def long():
         hwnd = GetParent(window.winfo_id())
@@ -134,12 +202,6 @@ def window_tiled(window: tk.Tk):
     res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~WS_TILED)
 
 
-def widget_max(widget: tk.Widget):
-    hwnd = GetParent(widget.winfo_id())
-    res = DefWindowProc(hwnd, WM_NCHITTEST, None, None)
-    print(res)
-
-
 def window_alpha(window: tk.Tk, alpha: int):
     hwnd = GetParent(window.winfo_id())
     res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~WS_SIZEBOX)
@@ -731,8 +793,10 @@ class DevTitleBar(tk.Frame):
         DevDrag(self, self.widget)
         self.window = window
         self.iswindow = iswindow
-
+        if iswindow:
+            window_move(self, window)
         if self.iswindow:
+
             if self.close:
                 self.closebutton.configure(command=self.widget_close)
             if self.max:
@@ -967,6 +1031,6 @@ class DevToplevel(tk.Toplevel, DevWindow):
 
 if __name__ == '__main__':
     Root = DevWindow()
-    Root.mica()
-    Root.screenshot()
+    window_popup(Root)
+    window_move(Root, Root)
     Root.run()
